/*-
 * Copyright (c) 2011 Marius Strobl <marius@smtpd.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: sig60.h,v 1.1 2012/02/15 22:08:01 marius Exp $
 */

#ifndef _SIG60_H_
#define	_SIG60_H_

/* register layout of the YAMAR SIG60 */

#define	SIG60_CR0	0
#define	SIG60_CR1	1

#define	SIG60_CR0_F1NF0		0x01	/* F0/F1 filter selection */
#define	SIG60_CR0_RLOOP_EN	0x02	/* remote loopback enable */
#define	SIG60_CR0_IFERHOP_EN	0x04	/* interference hoping enable */
#define	SIG60_CR0_LWUM_EN	0x08	/* long wake up message enable */
#define	SIG60_CR0_ASLEEP_DIS	0x10	/* auto sleep disable */
#define	SIG60_CR0_AWUM_DIS	0x20	/* auto wake up message disable */
#define	SIG60_CR0_LOOP_DIS	0x40	/* HDI to HDO loopback disable */
#define	SIG60_CR0_IFER		0x80	/* interference detected (RO) */

#define	SIG60_CR1_F_1750_4500	0x00	/* F0 1.75MHz F1 4.5MHz */
#define	SIG60_CR1_F_1750_5500	0x01	/* F0 1.75MHz F1 5.5MHz */
#define	SIG60_CR1_F_1750_6000	0x02	/* F0 1.75MHz F1 6.0MHz */
#define	SIG60_CR1_F_1750_6500	0x03	/* F0 1.75MHz F1 6.5MHz */
#define	SIG60_CR1_F_450_5500	0x04	/* F0 4.5MHz F1 5.5MHz */
#define	SIG60_CR1_F_450_6000	0x05	/* F0 4.5MHz F1 6.0MHz */
#define	SIG60_CR1_F_450_6500	0x06	/* F0 4.5MHz F1 6.5MHz */
#define	SIG60_CR1_F_450_10500	0x07	/* F0 4.5MHz F1 10.5MHz */
#define	SIG60_CR1_F_10500_13000	0x08	/* F0 10.5MHz F1 13.0MHz */
#define	SIG60_CR1_F_5500_10500	0x09	/* F0 5.5MHz F1 10.5MHz */
#define	SIG60_CR1_F_5500_1300	0x0a	/* F0 5.5MHz F1 13.0MHz */
#define	SIG60_CR1_F_6000_10500	0x0b	/* F0 6.0MHz F1 10.5MHz */
#define	SIG60_CR1_F_6000_13000	0x0c	/* F0 6.0MHz F1 13.0MHz */
#define	SIG60_CR1_F_6500_10500	0x0d	/* F0 6.5MHz F1 10.5MHz */
#define	SIG60_CR1_F_6500_13000	0x0e	/* F0 6.5MHz F1 13.0MHz */
#define	SIG60_CR1_F_5500_6500	0x0f	/* F0 5.5MHz F1 6.5MHz */
#define	SIG60_CR1_BR_38K4	0x00	/* 38.4Kbps */
#define	SIG60_CR1_BR_57K6	0x10	/* 57.6Kbps */
#define	SIG60_CR1_BR_9K6_115K2	0x20	/* 9.6Kbps(@ <10.5MHz)/115.2Kbps */
#define	SIG60_CR1_BR_19K2	0x30	/* 19.2Kbps */

#define	SIG60_CMD_RD		0x0d
#define	SIG60_CMD_WR		0x05
#define	SIG60_READ(reg)		(((reg) << 4) | SIG60_CMD_RD)
#define	SIG60_WRITE(reg)	(((reg) << 4) | SIG60_CMD_WR)

#endif
